@@ -1,12 +1,12 @@
 /*
     __ _____ _____ _____
  __|  |   __|     |   | |  JSON for Modern C++ (test suite)
-|  |  |__   |  |  | | | |  version 3.5.0
+|  |  |__   |  |  | | | |  version 3.7.3
 |_____|_____|_____|_|___|  https://github.com/nlohmann/json
 
 Licensed under the MIT License <http://opensource.org/licenses/MIT>.
 SPDX-License-Identifier: MIT
-Copyright (c) 2013-2018 Niels Lohmann <http://nlohmann.me>.
+Copyright (c) 2013-2019 Niels Lohmann <http://nlohmann.me>.
 
 Permission is hereby  granted, free of charge, to any  person obtaining a copy
 of this software and associated  documentation files (the "Software"), to deal
@@ -27,15 +27,23 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE  OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 */
 
-#include "catch.hpp"
+#include "doctest_compatibility.h"
+
+// for some reason including this after the json header leads to linker errors with VS 2017...
+#include <locale>
 
 #define private public
 #include <nlohmann/json.hpp>
 using nlohmann::json;
+#undef private
 
 #include <fstream>
+#include <sstream>
 #include <iostream>
+#include <iomanip>
 
+namespace
+{
 extern size_t calls;
 size_t calls = 0;
 
@@ -45,10 +53,10 @@ void check_utf8dump(bool success_expected, int byte1, int byte2 = -1, int byte3
 {
     std::string json_string;
 
-    CAPTURE(byte1);
-    CAPTURE(byte2);
-    CAPTURE(byte3);
-    CAPTURE(byte4);
+    CAPTURE(byte1)
+    CAPTURE(byte2)
+    CAPTURE(byte3)
+    CAPTURE(byte4)
 
     json_string += std::string(1, static_cast<char>(byte1));
 
@@ -67,7 +75,7 @@ void check_utf8dump(bool success_expected, int byte1, int byte2 = -1, int byte3
         json_string += std::string(1, static_cast<char>(byte4));
     }
 
-    CAPTURE(json_string);
+    CAPTURE(json_string)
 
     // store the string in a JSON value
     json j = json_string;
@@ -125,42 +133,44 @@ void check_utf8string(bool success_expected, int byte1, int byte2 = -1, int byte
 
     std::string json_string = "\"";
 
-    CAPTURE(byte1);
+    CAPTURE(byte1)
     json_string += std::string(1, static_cast<char>(byte1));
 
     if (byte2 != -1)
     {
-        CAPTURE(byte2);
+        CAPTURE(byte2)
         json_string += std::string(1, static_cast<char>(byte2));
     }
 
     if (byte3 != -1)
     {
-        CAPTURE(byte3);
+        CAPTURE(byte3)
         json_string += std::string(1, static_cast<char>(byte3));
     }
 
     if (byte4 != -1)
     {
-        CAPTURE(byte4);
+        CAPTURE(byte4)
         json_string += std::string(1, static_cast<char>(byte4));
     }
 
     json_string += "\"";
 
-    CAPTURE(json_string);
+    CAPTURE(json_string)
 
+    json _;
     if (success_expected)
     {
-        CHECK_NOTHROW(json::parse(json_string));
+        CHECK_NOTHROW(_ = json::parse(json_string));
     }
     else
     {
-        CHECK_THROWS_AS(json::parse(json_string), json::parse_error&);
+        CHECK_THROWS_AS(_ = json::parse(json_string), json::parse_error&);
     }
 }
+}
 
-TEST_CASE("Unicode", "[hide]")
+TEST_CASE("Unicode" * doctest::skip())
 {
     SECTION("RFC 3629")
     {
@@ -1041,8 +1051,9 @@ TEST_CASE("Unicode", "[hide]")
                 }
 
                 json_text += "\"";
-                CAPTURE(json_text);
-                CHECK_NOTHROW(json::parse(json_text));
+                CAPTURE(json_text)
+                json _;
+                CHECK_NOTHROW(_ = json::parse(json_text));
             }
         }
 
@@ -1050,32 +1061,34 @@ TEST_CASE("Unicode", "[hide]")
         {
             SECTION("incorrect surrogate values")
             {
-                CHECK_THROWS_AS(json::parse("\"\\uDC00\\uDC00\""), json::parse_error&);
-                CHECK_THROWS_WITH(json::parse("\"\\uDC00\\uDC00\""),
+                json _;
+
+                CHECK_THROWS_AS(_ = json::parse("\"\\uDC00\\uDC00\""), json::parse_error&);
+                CHECK_THROWS_WITH(_ = json::parse("\"\\uDC00\\uDC00\""),
                                   "[json.exception.parse_error.101] parse error at line 1, column 7: syntax error while parsing value - invalid string: surrogate U+DC00..U+DFFF must follow U+D800..U+DBFF; last read: '\"\\uDC00'");
 
-                CHECK_THROWS_AS(json::parse("\"\\uD7FF\\uDC00\""), json::parse_error&);
-                CHECK_THROWS_WITH(json::parse("\"\\uD7FF\\uDC00\""),
+                CHECK_THROWS_AS(_ = json::parse("\"\\uD7FF\\uDC00\""), json::parse_error&);
+                CHECK_THROWS_WITH(_ = json::parse("\"\\uD7FF\\uDC00\""),
                                   "[json.exception.parse_error.101] parse error at line 1, column 13: syntax error while parsing value - invalid string: surrogate U+DC00..U+DFFF must follow U+D800..U+DBFF; last read: '\"\\uD7FF\\uDC00'");
 
-                CHECK_THROWS_AS(json::parse("\"\\uD800]\""), json::parse_error&);
-                CHECK_THROWS_WITH(json::parse("\"\\uD800]\""),
+                CHECK_THROWS_AS(_ = json::parse("\"\\uD800]\""), json::parse_error&);
+                CHECK_THROWS_WITH(_ = json::parse("\"\\uD800]\""),
                                   "[json.exception.parse_error.101] parse error at line 1, column 8: syntax error while parsing value - invalid string: surrogate U+DC00..U+DFFF must be followed by U+DC00..U+DFFF; last read: '\"\\uD800]'");
 
-                CHECK_THROWS_AS(json::parse("\"\\uD800\\v\""), json::parse_error&);
-                CHECK_THROWS_WITH(json::parse("\"\\uD800\\v\""),
+                CHECK_THROWS_AS(_ = json::parse("\"\\uD800\\v\""), json::parse_error&);
+                CHECK_THROWS_WITH(_ = json::parse("\"\\uD800\\v\""),
                                   "[json.exception.parse_error.101] parse error at line 1, column 9: syntax error while parsing value - invalid string: surrogate U+DC00..U+DFFF must be followed by U+DC00..U+DFFF; last read: '\"\\uD800\\v'");
 
-                CHECK_THROWS_AS(json::parse("\"\\uD800\\u123\""), json::parse_error&);
-                CHECK_THROWS_WITH(json::parse("\"\\uD800\\u123\""),
+                CHECK_THROWS_AS(_ = json::parse("\"\\uD800\\u123\""), json::parse_error&);
+                CHECK_THROWS_WITH(_ = json::parse("\"\\uD800\\u123\""),
                                   "[json.exception.parse_error.101] parse error at line 1, column 13: syntax error while parsing value - invalid string: '\\u' must be followed by 4 hex digits; last read: '\"\\uD800\\u123\"'");
 
-                CHECK_THROWS_AS(json::parse("\"\\uD800\\uDBFF\""), json::parse_error&);
-                CHECK_THROWS_WITH(json::parse("\"\\uD800\\uDBFF\""),
+                CHECK_THROWS_AS(_ = json::parse("\"\\uD800\\uDBFF\""), json::parse_error&);
+                CHECK_THROWS_WITH(_ = json::parse("\"\\uD800\\uDBFF\""),
                                   "[json.exception.parse_error.101] parse error at line 1, column 13: syntax error while parsing value - invalid string: surrogate U+DC00..U+DFFF must be followed by U+DC00..U+DFFF; last read: '\"\\uD800\\uDBFF'");
 
-                CHECK_THROWS_AS(json::parse("\"\\uD800\\uE000\""), json::parse_error&);
-                CHECK_THROWS_WITH(json::parse("\"\\uD800\\uE000\""),
+                CHECK_THROWS_AS(_ = json::parse("\"\\uD800\\uE000\""), json::parse_error&);
+                CHECK_THROWS_WITH(_ = json::parse("\"\\uD800\\uE000\""),
                                   "[json.exception.parse_error.101] parse error at line 1, column 13: syntax error while parsing value - invalid string: surrogate U+DC00..U+DFFF must be followed by U+DC00..U+DFFF; last read: '\"\\uD800\\uE000'");
             }
         }
@@ -1090,7 +1103,7 @@ TEST_CASE("Unicode", "[hide]")
                 for (std::size_t cp = 0xD800u; cp <= 0xDBFFu; ++cp)
                 {
                     std::string json_text = "\"" + codepoint_to_unicode(cp) + "\"";
-                    CAPTURE(json_text);
+                    CAPTURE(json_text)
                     CHECK_THROWS_AS(json::parse(json_text), json::parse_error&);
                 }
             }
@@ -1109,7 +1122,7 @@ TEST_CASE("Unicode", "[hide]")
                         }
 
                         std::string json_text = "\"" + codepoint_to_unicode(cp1) + codepoint_to_unicode(cp2) + "\"";
-                        CAPTURE(json_text);
+                        CAPTURE(json_text)
                         CHECK_THROWS_AS(json::parse(json_text), json::parse_error&);
                     }
                 }
@@ -1122,7 +1135,7 @@ TEST_CASE("Unicode", "[hide]")
                 for (std::size_t cp = 0xDC00u; cp <= 0xDFFFu; ++cp)
                 {
                     std::string json_text = "\"" + codepoint_to_unicode(cp) + "\"";
-                    CAPTURE(json_text);
+                    CAPTURE(json_text)
                     CHECK_THROWS_AS(json::parse(json_text), json::parse_error&);
                 }
             }
@@ -1139,7 +1152,7 @@ TEST_CASE("Unicode", "[hide]")
         json j;
         CHECK_NOTHROW(f >> j);
 
-        // the array has 1112064 + 1 elemnts (a terminating "null" value)
+        // the array has 1112064 + 1 elements (a terminating "null" value)
         // Note: 1112064 = 0x1FFFFF code points - 2048 invalid values between
         // 0xD800 and 0xDFFF.
         CHECK(j.size() == 1112065);
@@ -1194,16 +1207,20 @@ TEST_CASE("Unicode", "[hide]")
 
     SECTION("error for incomplete/wrong BOM")
     {
-        CHECK_THROWS_AS(json::parse("\xef\xbb"), json::parse_error&);
-        CHECK_THROWS_AS(json::parse("\xef\xbb\xbb"), json::parse_error&);
+        json _;
+        CHECK_THROWS_AS(_ = json::parse("\xef\xbb"), json::parse_error&);
+        CHECK_THROWS_AS(_ = json::parse("\xef\xbb\xbb"), json::parse_error&);
     }
 }
 
+namespace
+{
 void roundtrip(bool success_expected, const std::string& s);
 
 void roundtrip(bool success_expected, const std::string& s)
 {
-    CAPTURE(s);
+    CAPTURE(s)
+    json _;
 
     // create JSON string value
     json j = s;
@@ -1219,11 +1236,11 @@ void roundtrip(bool success_expected, const std::string& s)
         if (s[0] != '\0')
         {
             // parsing JSON text succeeds
-            CHECK_NOTHROW(json::parse(ps));
+            CHECK_NOTHROW(_ = json::parse(ps));
         }
 
         // roundtrip succeeds
-        CHECK_NOTHROW(json::parse(j.dump()));
+        CHECK_NOTHROW(_ = json::parse(j.dump()));
 
         // after roundtrip, the same string is stored
         json jr = json::parse(j.dump());
@@ -1235,9 +1252,10 @@ void roundtrip(bool success_expected, const std::string& s)
         CHECK_THROWS_AS(j.dump(), json::type_error&);
 
         // parsing JSON text fails
-        CHECK_THROWS_AS(json::parse(ps), json::parse_error&);
+        CHECK_THROWS_AS(_ = json::parse(ps), json::parse_error&);
     }
 }
+}
 
 TEST_CASE("Markus Kuhn's UTF-8 decoder capability and stress test")
 {
